﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Data;
using System.Data.SqlClient;
using System.Configuration;

namespace Heb.DAL
{
    class DBHelper
    {

        string connStr = ConfigurationManager.ConnectionStrings["connStr"].ConnectionString;

        private SqlConnection conn;
        public SqlConnection Conn
        {
            get
            {
                if (conn == null)
                {
                    conn = new SqlConnection(connStr);
                }
                if (conn.State == ConnectionState.Closed)
                    conn.Open();
                if (conn.State == ConnectionState.Broken)
                {
                    conn.Close();
                    conn.Open();
                }
                return conn;
            } 
           
        }

        //查询:DataReader
        public SqlDataReader GetReader(string sqlStr)
        {
            try
            {
                SqlCommand cmd = new SqlCommand(sqlStr, Conn);
                return cmd.ExecuteReader();
            }
            catch (Exception)
            {
                throw;
            }
        }

        //查询:DataSet
        public DataTable GetTable(string sqlStr)
        {
            try
            {
                SqlDataAdapter dap = new SqlDataAdapter(sqlStr, Conn);
                DataTable dt = new DataTable();
                dap.Fill(dt);
                return dt;
            }
            catch (Exception)
            {
                throw;
            }
            finally
            {
                conn.Close();
            }
         
        }

        //查询:DataSet  参数化查询,有效防止Sql注入
        public DataTable GetTable(string sqlStr, SqlParameter[] paras)
        {
            //try
            //{
                SqlCommand cmd = new SqlCommand(sqlStr, Conn);
                cmd.Parameters.AddRange(paras);
                DataTable dt = new DataTable();
                SqlDataAdapter dap = new SqlDataAdapter(cmd);
                dap.Fill(dt);
                return dt;
            //}
            //catch
            //{
            //    throw new Exception("数据库读取数据失败!");
            //}
            //finally
            //{
            //   conn.Close();
            //}
          
        }

        //增改删
        public bool ExecuteNonQuery(string sqlStr)
        {
            SqlCommand cmd = new SqlCommand(sqlStr, Conn);
            int result = cmd.ExecuteNonQuery();
            conn.Close();
            return result > 0;
        }

        //增改删   参数化
        public bool ExecuteNonQuery(string sqlStr, SqlParameter[] paras)
        {
            SqlCommand cmd = new SqlCommand(sqlStr, Conn);
            cmd.Parameters.AddRange(paras);
            int result = cmd.ExecuteNonQuery();
            return result > 0;
        }


        //执行聚合函数
        public double ExecuteScalar(string SqlStr)
        {
            SqlCommand cmd = new SqlCommand(SqlStr, Conn);
            object obj = cmd.ExecuteScalar();
            conn.Close();
            return Convert.ToDouble(obj);
        }

        
        /// <summary>
        /// 执行查询 的存储过程,返回数据表
        /// </summary>
        /// <param name="procName">存储过程名</param>
        /// <param name="paras">参数</param>
        /// <returns>DataTable</returns>
        public DataTable ExecuteQueryProc(string procName, SqlParameter[] paras)
        {
            SqlCommand cmd = new SqlCommand(procName, Conn);
            cmd.CommandType = CommandType.StoredProcedure;
            if (paras!=null)
            {
                cmd.Parameters.AddRange(paras);
            }
            

            SqlDataAdapter dap = new SqlDataAdapter(cmd);
            DataTable dt = new DataTable();
            dap.Fill(dt);
            conn.Close(); 
            return dt;
        }
        /// <summary>
        /// 执行增,删,改 存储过程,并返回受影响的行数
        /// </summary>
        /// <param name="procName">存储过程名</param>
        /// <param name="paras">参数</param>
        /// <returns>int</returns>
        public int ExecuteNonQueryProc(string procName, SqlParameter[] paras)
        {
            SqlCommand cmd = new SqlCommand(procName, Conn);
            cmd.CommandType = CommandType.StoredProcedure;
            if (paras != null)
            {
                cmd.Parameters.AddRange(paras);
            }
            //影响行数
             int resultCount= cmd.ExecuteNonQuery();
             conn.Close();

             return resultCount;
        }

        //执行事务
        public bool ExecuteTransaction(string SqlStr,string tranName)
        {
            bool tranResult = false;
            //创建事务对象
            SqlTransaction tran = null;
            try
            {
                tran = Conn.BeginTransaction(tranName);
                SqlCommand cmd = new SqlCommand(SqlStr, Conn, tran);
                int result = cmd.ExecuteNonQuery();
                if (result > 0)
                {
                    tran.Commit();
                    tranResult = true;
                }
                else
                {
                    tran.Rollback(tranName);
                    tranResult = false;
                }
            }
            catch
            {
                tran.Rollback(tranName);
                tranResult = false;
            }
            finally
            {
                conn.Close();
                //tran.Dispose();
            }
            return tranResult;
         
        }
    }
}
